==> nextcloud-31.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/activity/l10n/et_EE.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Isiklik tegevuste voog %s",
    "Your feed URL is invalid" : "Sinu uudisvoo URL on vigane",
    "Activity feed for %1$s" : "%1$s tegevuste voog",
    "Activity feed" : "Tegevuste voog",
    "Your settings have been updated." : "Seaded on uuendatud.",
    "Settings have been updated." : "Seaded on uuendatud.",
    "Recent activity" : "Hiljutised tegevused",
    "No activities" : "Tegevusi pole",
    "More activities" : "Rohkem tegevusi",
    "Daily activity summary for %s" : "Päevase tegevuse kokkuvõte %s jaoks",
    "_and %n more…_::_and %n more…_" : ["ja %n veel...","ja %n veel..."],
    "All activities" : "Kõik tegevused",
    "By others" : "Teiste poolt",
    "By you" : "Sinu poolt",
    "Activity at %s" : "Tegevus %s",
    "Hello %s" : "Tere %s",
    "Hello %s," : "Tere %s,",
    "There was some activity at %s" : "Mõningane tegevus %s",
    "_and %n more _::_and %n more _" : ["ja %n veel","ja %n veel"],
    "Mail" : "Kirjad",
    "Push" : "Vajuta",
    "Activity" : "Tegevused",
    "Notifications" : "Teavitused",
    "This application enables people to view a log of activities about them, their files or other data." : "See rakendus võimaldab inimestel vaadata nende tegevust, nende faile või muid andmeid käsitlevat logi.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "See rakendus võimaldab inimestel Nextcloudis näha nende failide ja andmetega seotud toiminguid.\n\t\tIga inimene saab isiklikes seadetes konfigureerida oma individuaalseid tegevussätteid,\n\t\tet valida, millised tegevused edastatakse mobiiltelefonidele, saadetakse e-postiga\n\t\tvõi saadetakse iga hommik päevane kokkuvõte.\n\t\tLisateavet leiate tegevuse dokumentatsioonist.",
    "Send email" : "Saada e-kiri",
    "Send push notification" : "Push-teate saatmine",
    "Activity notification configuration" : "Tegevusest teavitamise konfiguratsioon",
    "Today" : "Täna",
    "Yesterday" : "Eile",
    "You need to set up your email address before you can receive notification emails." : "Enne teavituskirjade saamist pead sa lisama oma e-posti aadressi.",
    "Send activity emails" : "Saada tegevuste kohta e-kirju",
    "As soon as possible" : "Nii kiiresti kui võimalik",
    "Hourly" : "Iga tund",
    "Daily" : "Iga päev",
    "Weekly" : "Iga nädal",
    "You commented" : "Sa kommenteerisid",
    "Message deleted by author" : "Sõnum autori poolt kustutatud",
    "Open {filename}" : "Ava {filename} ",
    "in {path}" : "kataloogis {path}",
    "Home" : "Avaleht",
    "Could not load activities" : "Ei saanud tegevusi laadida",
    "Loading activities" : "Tegevuste laadimine",
    "This stream will show events like additions, changes & shares" : "See voog näitab sündmusi nagu lisamised, muudatused ja jagamised",
    "No activity yet" : "Tegevusi veel pole",
    "Loading more activities" : "Laen rohkem tegevusi",
    "No more activities." : "Pole rohkem tegevusi",
    "Could not enable RSS link" : "Ei saanud RSS linki lubada",
    "RSS link copied to clipboard" : "RSS-i link on lõikelauale kopeeritud",
    "Could not copy the RSS link, please copy manually:" : "Ei saanud RSS linki kopeerida, palun kopeeri manuaalselt:",
    "Activity settings" : "Tegevuste seaded",
    "Enable RSS feed" : "Luba RSS-voog",
    "RSS feed" : "RRS-voog",
    "Copy RSS feed link" : "Kopeeri RSS-voo link",
    "Personal notification settings" : "Isiklikud teavitamise seaded ",
    "Unable to load the activity list" : "Tegevuste nimekirja ei ole võimalik laadida ",
    "Choose for which activities you want to get an email or push notification." : "Vali, milliste tegevuste kohta soovid saada e-kirja või push-teateid.",
    "Choose for which activities you want to get a push notification." : "Vali, milliste tegevuste kohta soovid saada push-teateid.",
    "Notification" : "Teavitus",
    "Enable notification emails" : "Teavituskirjade lubamine ",
    "Daily activity summary" : "Päevase tegevuse kokkuvõte ",
    "Send daily activity summary in the morning" : "Saada hommikul igapäevane tegevuste kokkuvõte",
    "Default settings" : "Vaikeseaded",
    "Configure the default notification settings for new accounts." : "Seadista uute kontode vaikimisi teavituste seaded.",
    "Unable to save the settings" : "Seadeid ei saa salvestada",
    "No more events to load" : "Pole rohkem sündmusi, mida laadida"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-33.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/activity/l10n/et_EE.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Isiklik tegevuste voog %s",
    "Your feed URL is invalid" : "Sinu uudisvoo URL on vigane",
    "Activity feed for %1$s" : "%1$s tegevuste voog",
    "Activity feed" : "Tegevuste voog",
    "Your settings have been updated." : "Seaded on uuendatud.",
    "Settings have been updated." : "Seaded on uuendatud.",
    "remote user" : "kaugkasutaja",
    "Recent activity" : "Hiljutised tegevused",
    "No activities" : "Tegevusi pole",
    "More activities" : "Rohkem tegevusi",
    "Daily activity summary for %s" : "Päevase tegevuse kokkuvõte %s jaoks",
    "_and %n more…_::_and %n more…_" : ["ja %n veel...","ja %n veel..."],
    "You can disable daily digest emails in the <a href=\"%s\">settings</a>." : "Sa võid igapäevaste ülevaatekirjade saatmise <a href=\"%s\">seadistustest</a> välja lülitada.",
    "You can disable daily digest emails in the settings: %s" : "Sa võid igapäevaste ülevaatekirjade saatmise seadistustest välja lülitada: %s",
    "All activities" : "Kõik tegevused",
    "By others" : "Teiste poolt",
    "By you" : "Sinu poolt",
    "Activity at %s" : "Tegevus %s",
    "Hello %s" : "Tere %s",
    "Hello %s," : "Tere %s,",
    "There was some activity at %s" : "Mõningane tegevus %s",
    "_and %n more _::_and %n more _" : ["ja %n veel","ja %n veel"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Saad muuta nende e-kirjade sagedust või neid välja lülitada <a href=\"%s\">seadistustest</a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Saad muuta nende e-kirjade sagedust või neid välja lülitada seadistustest: %s",
    "Mail" : "Kirjad",
    "Push" : "Vajuta",
    "Activity" : "Tegevused",
    "Notifications" : "Teavitused",
    "This application enables people to view a log of activities about them, their files or other data." : "See rakendus võimaldab inimestel vaadata nende tegevust, nende faile või muid andmeid käsitlevat logi.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "See rakendus võimaldab inimestel Nextcloudis näha nende failide ja andmetega seotud toiminguid.\n\t\tIga inimene saab isiklikes seadetes konfigureerida oma individuaalseid tegevussätteid,\n\t\tet valida, millised tegevused edastatakse mobiiltelefonidele, saadetakse e-postiga\n\t\tvõi saadetakse iga hommik päevane kokkuvõte.\n\t\tLisateavet leiate tegevuse dokumentatsioonist.",
    "Send email" : "Saada e-kiri",
    "Send push notification" : "Saada tõuketeavitus",
    "Activity notification configuration" : "Tegevusest teavitamise konfiguratsioon",
    "Today" : "Täna",
    "Yesterday" : "Eile",
    "You need to set up your email address before you can receive notification emails." : "Enne teavituskirjade saamist pead sa lisama oma e-posti aadressi.",
    "Send activity emails" : "Saada tegevuste kohta e-kirju",
    "As soon as possible" : "Nii kiiresti kui võimalik",
    "Hourly" : "Kord tunnis",
    "Daily" : "Kord päevas",
    "Weekly" : "Kord nädalas",
    "You commented" : "Sa kommenteerisid",
    "Message deleted by author" : "Sõnum autori poolt kustutatud",
    "Open {filename}" : "Ava {filename} ",
    "in {path}" : "kataloogis {path}",
    "Home" : "Avaleht",
    "Could not load activities" : "Ei saanud tegevusi laadida",
    "Loading activities" : "Tegevuste laadimine",
    "This stream will show events like additions, changes & shares" : "See voog näitab sündmusi nagu lisamised, muudatused ja jagamised",
    "No activity yet" : "Tegevusi veel pole",
    "Loading more activities" : "Laen rohkem tegevusi",
    "No more activities." : "Pole rohkem tegevusi",
    "Could not enable RSS link" : "Ei saanud RSS linki lubada",
    "RSS link copied to clipboard" : "RSS-i link on lõikelauale kopeeritud",
    "Could not copy the RSS link, please copy manually:" : "Ei saanud RSS linki kopeerida, palun kopeeri manuaalselt:",
    "Activity settings" : "Tegevuste seaded",
    "Enable RSS feed" : "Luba RSS-voog",
    "RSS feed" : "RRS-voog",
    "Copy RSS feed link" : "Kopeeri uudisvoo link",
    "Personal notification settings" : "Isiklikud teavitamise seaded ",
    "Unable to load the activity list" : "Tegevuste nimekirja ei ole võimalik laadida ",
    "Choose for which activities you want to get an email or push notification." : "Vali, milliste tegevuste kohta soovid saada teavitusi e-kirjaga või tõuketeenustega.",
    "Choose for which activities you want to get a push notification." : "Vali, milliste tegevuste kohta soovid saada teavitusi tõuketeenustega.",
    "Notification" : "Teavitus",
    "Enable notification emails" : "Teavituskirjade lubamine ",
    "Daily activity summary" : "Päevase tegevuse kokkuvõte ",
    "Send daily activity summary in the morning" : "Saada hommikul igapäevane tegevuste kokkuvõte",
    "Default settings" : "Vaikeseaded",
    "Configure the default notification settings for new accounts." : "Seadista uute kontode vaikimisi teavituste seaded.",
    "Unable to save the settings" : "Seadeid ei saa salvestada",
    "No more events to load" : "Pole rohkem sündmusi, mida laadida"
},
"nplurals=2; plural=(n != 1);");
